/* Copyright (C) 1994 - 2003 artofcode LLC.  All rights reserved.
  
  This software is provided AS-IS with no warranty, either express or
  implied.
  
  This software is distributed under license and may not be copied,
  modified or distributed except as expressly authorized under the terms
  of the license contained in the file LICENSE in this distribution.
  
  For more information about licensing, please refer to
  http://www.ghostscript.com/licensing/. For information on
  commercial licensing, go to http://www.artifex.com/licensing/ or
  contact Artifex Software, Inc., 101 Lucas Valley Road #110,
  San Rafael, CA  94903, U.S.A., +1(415)492-9861.
*/

/* $Id: gp_mac.h 4133 2003-08-15 20:19:21Z giles $ */

#ifndef gp_mac_INCLUDED
#  define gp_mac_INCLUDED

/* no special definitions for macos */

#endif 				/* gp_mac_INCLUDED */

